@@ -737,6 +737,10 @@ panel_applet_frame_reload_response (GtkWidget        *dialog,
 			panel_profile_delete_object (info);
 	}
 
+	 frame->priv->panel->open_dialogs = 
+					g_slist_remove (
+					frame->priv->panel->open_dialogs,
+					dialog);
 	g_object_unref (frame);
 	gtk_widget_destroy (dialog);
 }
@@ -813,6 +817,10 @@ panel_applet_frame_cnx_broken (PanelAppletFrame *frame)
 			  G_CALLBACK (panel_applet_frame_reload_response),
 			  g_object_ref (frame));
 
+	frame->priv->panel->open_dialogs 
+				= g_slist_append (
+					frame->priv->panel->open_dialogs,
+					dialog);
 	gtk_widget_show (dialog);
 	g_free (applet_name);
 	g_free (txt);
