@@ -77,7 +77,7 @@ struct _PanelWidget
 
 	GList          *applet_list;
 
-	GSList         *create_launcher_dialog_list;	
+	GSList         *open_dialogs;	
 
 	int             size;
 	GtkOrientation  orient;
